==> react-layout-grid-2.14.0.tgz: package/lib/gridItem/index.js <==
import { useMemo } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import PolymorphicElement from '@s-ui/react-primitive-polymorphic-element';
import { BASE_CLASS, CELL_NUMBERS } from '../settings.js';
import { getColSpanClassNamesTransform } from './settings.js';
import { jsx as _jsx } from "react/jsx-runtime";
export default function LayoutGridItem(_ref) {
  var _ref$as = _ref.as,
    as = _ref$as === void 0 ? 'div' : _ref$as,
    children = _ref.children,
    className = _ref.className,
    _ref$colSpan = _ref.colSpan,
    colSpan = _ref$colSpan === void 0 ? 1 : _ref$colSpan,
    l = _ref.l,
    lOffset = _ref.lOffset,
    m = _ref.m,
    mOffset = _ref.mOffset,
    s = _ref.s,
    sOffset = _ref.sOffset,
    xl = _ref.xl,
    xlOffset = _ref.xlOffset,
    xs = _ref.xs,
    xsOffset = _ref.xsOffset,
    xxl = _ref.xxl,
    xxlOffset = _ref.xxlOffset,
    xxs = _ref.xxs,
    xxsOffset = _ref.xxsOffset;
  var spanClassnames = useMemo(function () {
    return getColSpanClassNamesTransform({
      colSpan: colSpan,
      xxl: xxl,
      xl: xl,
      l: l,
      m: m,
      s: s,
      xs: xs,
      xxs: xxs
    });
  }, [colSpan, xxl, xl, l, m, s, xs, xxs]);
  var classNames = cx(BASE_CLASS + "-item", spanClassnames, xxsOffset && BASE_CLASS + "-item--xxsOffset-" + xxsOffset, xsOffset && BASE_CLASS + "-item--xsOffset-" + xsOffset, sOffset && BASE_CLASS + "-item--sOffset-" + sOffset, mOffset && BASE_CLASS + "-item--mOffset-" + mOffset, lOffset && BASE_CLASS + "-item--lOffset-" + lOffset, xlOffset && BASE_CLASS + "-item--xlOffset-" + xlOffset, xxlOffset && BASE_CLASS + "-item--xxlOffset-" + xxlOffset, className);
  return /*#__PURE__*/_jsx(PolymorphicElement, {
    as: as,
    className: classNames,
    children: children
  });
}
LayoutGridItem.displayName = 'LayoutGridItem';

==> react-layout-grid-2.15.0.tgz: package/lib/gridItem/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["as", "children", "className", "colSpan", "l", "lOffset", "m", "mOffset", "s", "sOffset", "xl", "xlOffset", "xs", "xsOffset", "xxl", "xxlOffset", "xxs", "xxsOffset"];
import { useMemo } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import PolymorphicElement from '@s-ui/react-primitive-polymorphic-element';
import { BASE_CLASS, CELL_NUMBERS } from '../settings.js';
import { getColSpanClassNamesTransform } from './settings.js';
import { jsx as _jsx } from "react/jsx-runtime";
export default function LayoutGridItem(_ref) {
  var _ref$as = _ref.as,
    as = _ref$as === void 0 ? 'div' : _ref$as,
    children = _ref.children,
    className = _ref.className,
    _ref$colSpan = _ref.colSpan,
    colSpan = _ref$colSpan === void 0 ? 1 : _ref$colSpan,
    l = _ref.l,
    lOffset = _ref.lOffset,
    m = _ref.m,
    mOffset = _ref.mOffset,
    s = _ref.s,
    sOffset = _ref.sOffset,
    xl = _ref.xl,
    xlOffset = _ref.xlOffset,
    xs = _ref.xs,
    xsOffset = _ref.xsOffset,
    xxl = _ref.xxl,
    xxlOffset = _ref.xxlOffset,
    xxs = _ref.xxs,
    xxsOffset = _ref.xxsOffset,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  var spanClassnames = useMemo(function () {
    return getColSpanClassNamesTransform({
      colSpan: colSpan,
      xxl: xxl,
      xl: xl,
      l: l,
      m: m,
      s: s,
      xs: xs,
      xxs: xxs
    });
  }, [colSpan, xxl, xl, l, m, s, xs, xxs]);
  var classNames = cx(BASE_CLASS + "-item", spanClassnames, xxsOffset && BASE_CLASS + "-item--xxsOffset-" + xxsOffset, xsOffset && BASE_CLASS + "-item--xsOffset-" + xsOffset, sOffset && BASE_CLASS + "-item--sOffset-" + sOffset, mOffset && BASE_CLASS + "-item--mOffset-" + mOffset, lOffset && BASE_CLASS + "-item--lOffset-" + lOffset, xlOffset && BASE_CLASS + "-item--xlOffset-" + xlOffset, xxlOffset && BASE_CLASS + "-item--xxlOffset-" + xxlOffset, className);
  return /*#__PURE__*/_jsx(PolymorphicElement, _extends({
    as: as,
    className: classNames
  }, props, {
    children: children
  }));
}
LayoutGridItem.displayName = 'LayoutGridItem';
